@@ -20,8 +20,8 @@ except ImportError:
         raise
 
 
-version = "0.3.0"
-version_info = (0, 3, 0, 0)
+version = "0.4.0"
+version_info = (0, 4, 0, 0)
 
 class Connection(object):
     """A lightweight wrapper around MySQLdb DB-API connections.
@@ -40,15 +40,14 @@ class Connection(object):
     UTF-8 on all connections to avoid time zone and encoding errors.
     """
     def __init__(self, host, database, user=None, password=None, auto_commit=True,
-                 use_charset='utf8',max_idle_time=7 * 3600, connect_timeout=0,
-                 time_zone="+8:00"):
+                 use_charset='utf8',max_idle_time=7 * 3600, connect_timeout=0):
         self.host = host
         self.database = database
         self.max_idle_time = float(max_idle_time)
         self.auto_commit = auto_commit
 
         args = dict(conv=CONVERSIONS, use_unicode=True, charset=use_charset,
-                    db=database, init_command=('SET time_zone = "%s"' % time_zone),
+                    db=database, init_command=None,
                     connect_timeout=connect_timeout, sql_mode="TRADITIONAL")
         if user is not None:
             args["user"] = user
@@ -144,7 +143,9 @@ class Connection(object):
             rows = [row[0] for row in cursor]
         finally:
             cursor.close()
-        if len(rows) == 1:
+        if len(rows) == 0:
+            return None
+        elif len(rows) == 1:
             return rows[0]
         else:
             raise Exception("Multiple rows returned for Database.one() query")
